==> estateplat-common-1.2.4-20210319.024944-675-sources.jar: cn/gtmap/estateplat/model/server/core/DjsjCbjyq.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;
/**
 * @author <a href="mailto:jiangganzhi@gtmap.cn">jiangganzhi</a>
 * @version V1.0, 2021/3/16
 * @description 土地承包经营权
 */
@Table(name = "DJSJ_CBJYQ")
public class DjsjCbjyq {
    @Id
    private String cbzd_dcb_index;
    private String dkmc;
    private Date cbkssj;
    private Date cbjssj;
    private Double cbmj;
    private String tdsyqxz;
    private String syttlx;
    private String yzyfs;
    private Integer syzcl;
    private String fbfqc;
    private String fbffzr;
    private String fbflxdh;
    private String zdszd;
    private String zdszn;
    private String zdszx;
    private String zdszb;
    private String qqfs;
    private String bdcdyh;
    private String cbfmc;
    private String cbhtbh;
    private String qsxz;
    private String tdyt;
    private String zldj;
    private String sfjbnt;
    private Double scmj;

    public String getCbzd_dcb_index() {
        return cbzd_dcb_index;
    }

    public void setCbzd_dcb_index(String cbzd_dcb_index) {
        this.cbzd_dcb_index = cbzd_dcb_index;
    }

    public String getDkmc() {
        return dkmc;
    }

    public void setDkmc(String dkmc) {
        this.dkmc = dkmc;
    }

    public Date getCbkssj() {
        return cbkssj;
    }

    public void setCbkssj(Date cbkssj) {
        this.cbkssj = cbkssj;
    }

    public Date getCbjssj() {
        return cbjssj;
    }

    public void setCbjssj(Date cbjssj) {
        this.cbjssj = cbjssj;
    }

    public Double getCbmj() {
        return cbmj;
    }

    public void setCbmj(Double cbmj) {
        this.cbmj = cbmj;
    }

    public String getTdsyqxz() {
        return tdsyqxz;
    }

    public void setTdsyqxz(String tdsyqxz) {
        this.tdsyqxz = tdsyqxz;
    }

    public String getSyttlx() {
        return syttlx;
    }

    public void setSyttlx(String syttlx) {
        this.syttlx = syttlx;
    }

    public String getYzyfs() {
        return yzyfs;
    }

    public void setYzyfs(String yzyfs) {
        this.yzyfs = yzyfs;
    }

    public Integer getSyzcl() {
        return syzcl;
    }

    public void setSyzcl(Integer syzcl) {
        this.syzcl = syzcl;
    }

    public String getFbfqc() {
        return fbfqc;
    }

    public void setFbfqc(String fbfqc) {
        this.fbfqc = fbfqc;
    }

    public String getFbffzr() {
        return fbffzr;
    }

    public void setFbffzr(String fbffzr) {
        this.fbffzr = fbffzr;
    }

    public String getFbflxdh() {
        return fbflxdh;
    }

    public void setFbflxdh(String fbflxdh) {
        this.fbflxdh = fbflxdh;
    }

    public String getZdszd() {
        return zdszd;
    }

    public void setZdszd(String zdszd) {
        this.zdszd = zdszd;
    }

    public String getZdszn() {
        return zdszn;
    }

    public void setZdszn(String zdszn) {
        this.zdszn = zdszn;
    }

    public String getZdszx() {
        return zdszx;
    }

    public void setZdszx(String zdszx) {
        this.zdszx = zdszx;
    }

    public String getZdszb() {
        return zdszb;
    }

    public void setZdszb(String zdszb) {
        this.zdszb = zdszb;
    }

    public String getQqfs() {
        return qqfs;
    }

    public void setQqfs(String qqfs) {
        this.qqfs = qqfs;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public String getCbfmc() {
        return cbfmc;
    }

    public void setCbfmc(String cbfmc) {
        this.cbfmc = cbfmc;
    }

    public String getCbhtbh() {
        return cbhtbh;
    }

    public void setCbhtbh(String cbhtbh) {
        this.cbhtbh = cbhtbh;
    }

    public String getQsxz() {
        return qsxz;
    }

    public void setQsxz(String qsxz) {
        this.qsxz = qsxz;
    }

    public String getTdyt() {
        return tdyt;
    }

    public void setTdyt(String tdyt) {
        this.tdyt = tdyt;
    }

    public String getZldj() {
        return zldj;
    }

    public void setZldj(String zldj) {
        this.zldj = zldj;
    }

    public String getSfjbnt() {
        return sfjbnt;
    }

    public void setSfjbnt(String sfjbnt) {
        this.sfjbnt = sfjbnt;
    }

    public Double getScmj() {
        return scmj;
    }

    public void setScmj(Double scmj) {
        this.scmj = scmj;
    }
}

==> estateplat-common-1.2.4-20210329.073827-687-sources.jar: cn/gtmap/estateplat/model/server/core/DjsjCbjyq.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;
/**
 * @author <a href="mailto:jiangganzhi@gtmap.cn">jiangganzhi</a>
 * @version V1.0, 2021/3/16
 * @description 土地承包经营权
 */
@Table(name = "DJSJ_CBJYQ")
public class DjsjCbjyq {
    @Id
    private String cbzd_dcb_index;
    private String dkmc;
    private Date cbkssj;
    private Date cbjssj;
    private Double cbmj;
    private String tdsyqxz;
    private String syttlx;
    private String yzyfs;
    private Integer syzcl;
    private String fbfqc;
    private String fbffzr;
    private String fbflxdh;
    private String zdszd;
    private String zdszn;
    private String zdszx;
    private String zdszb;
    private String qqfs;
    private String bdcdyh;
    private String cbfmc;
    private String cbhtbh;
    private String qsxz;
    private String tdyt;
    private String zldj;
    private String sfjbnt;
    private Double scmj;
    private Double htmjm;
    private String fbfbm;
    private String qdcbfs;

    public String getCbzd_dcb_index() {
        return cbzd_dcb_index;
    }

    public void setCbzd_dcb_index(String cbzd_dcb_index) {
        this.cbzd_dcb_index = cbzd_dcb_index;
    }

    public String getDkmc() {
        return dkmc;
    }

    public void setDkmc(String dkmc) {
        this.dkmc = dkmc;
    }

    public Date getCbkssj() {
        return cbkssj;
    }

    public void setCbkssj(Date cbkssj) {
        this.cbkssj = cbkssj;
    }

    public Date getCbjssj() {
        return cbjssj;
    }

    public void setCbjssj(Date cbjssj) {
        this.cbjssj = cbjssj;
    }

    public Double getCbmj() {
        return cbmj;
    }

    public void setCbmj(Double cbmj) {
        this.cbmj = cbmj;
    }

    public String getTdsyqxz() {
        return tdsyqxz;
    }

    public void setTdsyqxz(String tdsyqxz) {
        this.tdsyqxz = tdsyqxz;
    }

    public String getSyttlx() {
        return syttlx;
    }

    public void setSyttlx(String syttlx) {
        this.syttlx = syttlx;
    }

    public String getYzyfs() {
        return yzyfs;
    }

    public void setYzyfs(String yzyfs) {
        this.yzyfs = yzyfs;
    }

    public Integer getSyzcl() {
        return syzcl;
    }

    public void setSyzcl(Integer syzcl) {
        this.syzcl = syzcl;
    }

    public String getFbfqc() {
        return fbfqc;
    }

    public void setFbfqc(String fbfqc) {
        this.fbfqc = fbfqc;
    }

    public String getFbffzr() {
        return fbffzr;
    }

    public void setFbffzr(String fbffzr) {
        this.fbffzr = fbffzr;
    }

    public String getFbflxdh() {
        return fbflxdh;
    }

    public void setFbflxdh(String fbflxdh) {
        this.fbflxdh = fbflxdh;
    }

    public String getZdszd() {
        return zdszd;
    }

    public void setZdszd(String zdszd) {
        this.zdszd = zdszd;
    }

    public String getZdszn() {
        return zdszn;
    }

    public void setZdszn(String zdszn) {
        this.zdszn = zdszn;
    }

    public String getZdszx() {
        return zdszx;
    }

    public void setZdszx(String zdszx) {
        this.zdszx = zdszx;
    }

    public String getZdszb() {
        return zdszb;
    }

    public void setZdszb(String zdszb) {
        this.zdszb = zdszb;
    }

    public String getQqfs() {
        return qqfs;
    }

    public void setQqfs(String qqfs) {
        this.qqfs = qqfs;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public String getCbfmc() {
        return cbfmc;
    }

    public void setCbfmc(String cbfmc) {
        this.cbfmc = cbfmc;
    }

    public String getCbhtbh() {
        return cbhtbh;
    }

    public void setCbhtbh(String cbhtbh) {
        this.cbhtbh = cbhtbh;
    }

    public String getQsxz() {
        return qsxz;
    }

    public void setQsxz(String qsxz) {
        this.qsxz = qsxz;
    }

    public String getTdyt() {
        return tdyt;
    }

    public void setTdyt(String tdyt) {
        this.tdyt = tdyt;
    }

    public String getZldj() {
        return zldj;
    }

    public void setZldj(String zldj) {
        this.zldj = zldj;
    }

    public String getSfjbnt() {
        return sfjbnt;
    }

    public void setSfjbnt(String sfjbnt) {
        this.sfjbnt = sfjbnt;
    }

    public Double getScmj() {
        return scmj;
    }

    public void setScmj(Double scmj) {
        this.scmj = scmj;
    }

    public Double getHtmjm() {
        return htmjm;
    }

    public void setHtmjm(Double htmjm) {
        this.htmjm = htmjm;
    }

    public String getFbfbm() {
        return fbfbm;
    }

    public void setFbfbm(String fbfbm) {
        this.fbfbm = fbfbm;
    }

    public String getQdcbfs() {
        return qdcbfs;
    }

    public void setQdcbfs(String qdcbfs) {
        this.qdcbfs = qdcbfs;
    }
}
